/*
    qtparted - a frontend to libparted for manipulating disk partitions
    Copyright (C) 2002-2003 Vanni Brutto

    Vanni Brutto <zanac (-at-) libero dot it>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <qpixmap.h>
#include <qmessagebox.h>
#include "qp_drivelist.h"
#include "qp_libparted.h"
#include "xpm/tool_disk.xpm"

QP_DriveList::QP_DriveList(QWidget *parent, const char *name)
    :QListView(parent, name) {

    setAllColumnsShowFocus(true);
    addColumn("Device");

    buildView();

    connect(this, SIGNAL(selectionChanged(QListViewItem *)),
            this, SLOT(itemSelected(QListViewItem *)));
}

QP_DriveList::~QP_DriveList() { 
}

void QP_DriveList::buildView() {
    QListViewItem *ideRoot = new QListViewItem(this, "IDE Disks");

    QStrList lst = QP_LibParted::device_probe();
    if (lst.count() == 0) {
        QMessageBox::information(this, "QTParted",
                QString(tr("No device found. Maybe you're not using root user?")));
    }
    
    for (uint i = 0; i < lst.count(); ++i) {
        QString st = lst.at(i);
        addDevice(st, ideRoot);
    }

    if (ideRoot->childCount())
        ideRoot->setOpen( true );
    else
        delete ideRoot;
}

void QP_DriveList::addDevice(QString dev, QListViewItem *parent) {
    QListViewItem *item = new QListViewItem(parent, dev);
    item->setPixmap(0, QPixmap(tool_disk));
}

void QP_DriveList::itemSelected(QListViewItem *item) {
    if (!item->childCount())
        emit selected(item->text(0));
}

